@@ -78,7 +78,7 @@ public:
 	void set_power_control(double val);
 	int  get_power_control();
 	void get_pc_min_max_step(double &min, double &max, double &step) {
-		min = 5; max = 100; step = 1; }
+		min = 5; pmax = max = 100; step = 1; }
 
 	void set_if_shift(int val);
 	bool get_if_shift(int &val);
