@@ -138,7 +138,7 @@ public:
 	void set_power_control(double val);
 	int  get_power_control(void);
 	void get_pc_min_max_step(double &min, double &max, double &step) {
-		min = 0; max = 200; step = 1; }
+		min = 0; pmax = max = 200; step = 1; }
 	int  get_power_out();
 
 	void set_PTT_control(int val);
