@@ -397,10 +397,11 @@ public:
 	virtual int  get_power_out(void) {return -1;}
 
 int po_, po_val;
+int pmax;
 	virtual int  get_power_control(void) {return po_;}
 	virtual void set_power_control(double val) {po_ = val;}
 	virtual void get_pc_min_max_step(double &min, double &max, double &step) {
-		min = 0; max = 100; step = 1; }
+		min = 0; pmax = max = 100; step = 1; }
 
 int vl_;
 	virtual void set_volume_control(int val) {vl_ = val;}
@@ -539,7 +540,8 @@ int vfo_;
 	virtual void get_cw_wpm_min_max(int &min, int &max) {
 		min = 5; max = 50; } // default for FT950/FT450D
 	virtual void enable_keyer() {}
-	virtual void enable_break_in() {}
+	virtual void set_break_in() {}
+	virtual int  get_break_in() {return 0;}
 
 	virtual void set_cw_qsk() {}
 	virtual void get_cw_qsk_min_max_step(double &min, double &max, double &step) {
@@ -641,6 +643,8 @@ int vfo_;
 
 	string bcd255(int val);
 	int    num100(string bcd);
+	int    hexval(int hex);
+	int    hex2val(string hexval);
 
 // Yaesu force ID response before sending command
 	std::string IDstr;
@@ -649,7 +653,12 @@ int vfo_;
 
 // KX3 power scale
 	int powerScale;
-	virtual int power_scale() { return 1; }
+	virtual int power_scale() { 
+		return 1; 
+	}
+	virtual int power_max() {
+		return pmax;
+	}
 };
 
 extern rigbase *rigs[];
