@@ -96,6 +96,7 @@ extern void setAttControl(void *);
 extern void setMicGainControl(void *);
 extern void setAGC(void *);
 extern void setRFGAINControl(void *);
+extern void update_power_control(void *);
 
 extern void setMode();
 extern void setBW();
@@ -137,7 +138,7 @@ extern void cb_cw_qsk();
 extern void cb_cw_delay();
 extern void cb_cw_weight();
 extern void cb_enable_keyer();
-extern void cb_enable_break_in();
+extern void cb_set_break_in();
 
 extern void cb_vox_gain();
 extern void cb_vox_anti();
@@ -368,4 +369,8 @@ extern Fl_Tree *tab_tree;
 
 extern void select_tab(const char *);
 
+extern void update_progress(int);
+
+extern bool xcvr_online;
+
 #endif
