@@ -136,6 +136,7 @@ RIG_FT2000::RIG_FT2000() {
 	has_ifshift_control =
 	has_ptt_control =
 	has_tune_control =
+	has_cw_break_in =
 	has_swr_control = true;
 	
 // derived specific
@@ -942,3 +943,32 @@ void RIG_FT2000::get_mic_min_max_step(int &min, int &max, int &step)
 	max = 100;
 	step = 1;
 }
+
+void RIG_FT2000::set_break_in()
+{
+	if (progStatus.break_in) {
+		cmd = "BI1;";
+		break_in_label("BK-IN");
+	} else {
+		cmd = "BI0;";
+		break_in_label("QSK ?");
+	}
+	sendCommand(cmd);
+	showresp(WARN, ASC, "SET break in on/off", cmd, replystr);
+	sett("set_break_in");
+}
+
+int RIG_FT2000::get_break_in()
+{
+	cmd = "BI;";
+	wait_char(';', 4, 100, "get break in", ASC);
+	progStatus.break_in = (replystr[2] == '1');
+	if (progStatus.break_in) {
+		break_in_label("BK-IN");
+		progStatus.cw_delay = 0;
+	} else {
+		break_in_label("QSK ?");
+//		get_qsk_delay();
+	}
+	return progStatus.break_in;
+}
