@@ -1552,9 +1552,17 @@ void RIG_FT950::set_xcvr_auto_on()
 	if (p == string::npos) {	// rig is off, power on
 		cmd = "PS1;";
 		sendCommand(cmd);
-		MilliSleep(1500);	// 1.0 < T < 2.0 seconds
+		for (int i = 0; i < 1500; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 4500);
+			Fl::awake();
+		}
 		sendCommand(cmd);
-		MilliSleep(3000);	// Wait for rig startup?  Maybe not needed.
+		for (int i = 1500; i < 4500; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 4500);
+			Fl::awake();
+		}
 	}
 }
 
