@@ -157,6 +157,7 @@ RIG_FT991::RIG_FT991() {
 	has_cw_spot_tone =
 	has_cw_qsk =
 	has_cw_weight =
+	has_cw_break_in =
 
 	can_change_alt_vfo =
 	has_smeter =
@@ -1383,3 +1384,32 @@ void RIG_FT991::get_vfoadj_min_max_step(int &min, int &max, int &step)
 	step = 1;
 }
 
+void RIG_FT991::set_break_in()
+{
+	if (progStatus.break_in) {
+		cmd = "BI1;";
+		break_in_label("BK-IN");
+	} else {
+		cmd = "BI0;";
+		break_in_label("QSK ?");
+	}
+	sendCommand(cmd);
+	showresp(WARN, ASC, "SET break in on/off", cmd, replystr);
+	sett("set_break_in");
+}
+
+int RIG_FT991::get_break_in()
+{
+	cmd = "BI;";
+	wait_char(';', 4, FL991_WAIT_TIME, "get break in", ASC);
+	progStatus.break_in = (replystr[2] == '1');
+	if (progStatus.break_in) {
+		break_in_label("BK-IN");
+		progStatus.cw_delay = 0;
+	} else {
+		break_in_label("QSK ?");
+//		get_qsk_delay();
+	}
+	return progStatus.break_in;
+}
+
