@@ -159,6 +159,7 @@ RIG_FTdx1200::RIG_FTdx1200() {
 	has_cw_spot_tone =
 	has_cw_qsk =
 	has_cw_weight =
+	has_cw_break_in =
 
 	can_change_alt_vfo =
 	has_smeter =
@@ -1545,9 +1546,17 @@ void RIG_FTdx1200::set_xcvr_auto_on()
 	if (p == string::npos) {	// rig is off, power on
 		cmd = "PS1;";
 		sendCommand(cmd);
-		MilliSleep(1500);	// 1.0 < T < 2.0 seconds
+		for (int i = 0; i < 1500; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 4500);
+			Fl::awake();
+		}
 		sendCommand(cmd);
-		MilliSleep(3000);	// Wait for rig startup?  Maybe not needed.
+		for (int i = 1500; i < 4500; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 4500);
+			Fl::awake();
+		}
 	}
 }
 
@@ -1581,6 +1590,35 @@ void RIG_FTdx1200::set_compression(int on, int val)
 	}
 }
 
+void RIG_FTdx1200::set_break_in()
+{
+	if (progStatus.break_in) {
+		cmd = "BI1;";
+		break_in_label("BK-IN");
+	} else {
+		cmd = "BI0;";
+		break_in_label("QSK ?");
+	}
+	sendCommand(cmd);
+	showresp(WARN, ASC, "SET break in on/off", cmd, replystr);
+	sett("set_break_in");
+}
+
+int RIG_FTdx1200::get_break_in()
+{
+	cmd = "BI;";
+	wait_char(';', 4, 100, "get break in", ASC);
+	progStatus.break_in = (replystr[2] == '1');
+	if (progStatus.break_in) {
+		break_in_label("BK-IN");
+		progStatus.cw_delay = 0;
+	} else {
+		break_in_label("QSK ?");
+//		get_qsk_delay();
+	}
+	return progStatus.break_in;
+}
+
 /*
 // Audio Peak Filter, like set_cw_spot
 bool RIG_FTdx1200::set_cw_APF()
