@@ -23,12 +23,16 @@
 #include <iostream>
 #include <sstream>
 
+#include "tod_clock.h"
+#include "support.h"
+
 //=============================================================================
 // IC-7100
 /*
 
 */
 
+
 const char IC7100name_[] = "IC-7100";
 
 static int nummodes = 14;
@@ -230,6 +234,7 @@ RIG_IC7100::RIG_IC7100() {
 	has_cw_wpm = true;
 	has_cw_spot_tone = true;
 	has_cw_qsk = true;
+	has_cw_break_in = true;
 	has_cw_vol = true;
 
 	has_vox_onoff = true;
@@ -270,23 +275,30 @@ RIG_IC7100::RIG_IC7100() {
 
 void RIG_IC7100::set_xcvr_auto_on()
 {
-	cmd.clear();
 	int nr = progStatus.comm_baudrate == 6 ? 25 :
 			 progStatus.comm_baudrate == 5 ? 13 :
 			 progStatus.comm_baudrate == 4 ? 7 :
 			 progStatus.comm_baudrate == 3 ? 3 : 2;
-	cmd.append( nr, '\xFE');
-	cmd.append(pre_to);
-	cmd += '\x18'; cmd += '\x01';
-	cmd.append(post);
-	waitFB("Power ON", 2000);
-	isett("Power ON");
 
-	cmd = pre_to;
+	cmd.assign(pre_to);
 	cmd += '\x19'; cmd += '\x00';
 	cmd.append(post);
-	waitFOR(8, "get ID", 10000);
-	igett("get ID");
+
+	if (waitFOR(8, "get ID", 100) == false) {  // xcvr must be OFF
+		cmd.assign( nr, '\xFE');
+		cmd.append(pre_to);
+		cmd += '\x18'; cmd += '\x01';
+		cmd.append(post);
+		waitFB("Power ON", 2000);
+		isett("Power ON");
+// wake up time for initialization
+		for (int i = 0; i < 5000; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 5000);
+			Fl::awake();
+		}
+	}
+	return;
 }
 
 void RIG_IC7100::set_xcvr_auto_off()
@@ -320,7 +332,7 @@ void RIG_IC7100::selectA()
 	cmd += '\x07';
 	cmd += '\x00';
 	cmd.append(post);
-	set_trace(2, "selectA()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "selectA()", hexstr(cmd).c_str());
 	waitFB("select A");
 	igett("select A");
 	IC7100onA = true;
@@ -543,7 +555,7 @@ int RIG_IC7100::get_modeA()
 	if (A.filter > 0 && A.filter < 4)
 		mode_filterA[A.imode] = A.filter;
 
-	get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_data_modeA()", hexstr(replystr).c_str());
 	get_trace(4, "mode_filterA[", IC7100modes_[md], "] = ", szfilter[A.filter-1]);
 
 	if (A.imode == CW7100 || A.imode == CWR7100) {
@@ -644,7 +656,7 @@ int RIG_IC7100::get_modeB()
 	if (B.filter > 0 && B.filter < 4)
 		mode_filterA[B.imode] = B.filter;
 
-	get_trace(2, "get_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_data_modeB()", hexstr(replystr).c_str());
 	get_trace(4, "mode_filterB[", IC7100modes_[md], "] = ", szfilter[A.filter-1]);
 
 	if (B.imode == CW7100 || B.imode == CWR7100) {
@@ -821,7 +833,7 @@ void RIG_IC7100::set_mic_gain(int val)
 	cmd.append("\x14\x0B");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(2, "set_mic_gain()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_mic_gain()", hexstr(cmd).c_str());
 	waitFB("set mic gain");
 }
 
@@ -839,7 +851,7 @@ int RIG_IC7100::get_mic_gain()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
-	get_trace(2, "get_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_mic_gain()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -862,7 +874,7 @@ void RIG_IC7100::set_attenuator(int val)
 	cmd += '\x11';
 	cmd += atten_level ? '\x12' : '\x00';
 	cmd.append( post );
-	set_trace(2, "set_attenuator()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_attenuator()", hexstr(cmd).c_str());
 	waitFB("set att");
 }
 
@@ -874,7 +886,7 @@ int RIG_IC7100::get_attenuator()
 	string resp = pre_fm;
 	resp += '\x11';
 	if (waitFOR(7, "get ATT")) {
-		get_trace(2, "get_ATT()", str2hex(replystr.c_str(), replystr.length()));
+		get_trace(2, "get_ATT()", hexstr(replystr).c_str());
 		size_t p = replystr.rfind(resp);
 		if (replystr[p+5] == 0x12) {
 			atten_level = 1;
@@ -946,7 +958,7 @@ void RIG_IC7100::set_preamp(int val)
 	waitFB(	(preamp_level == 0) ? "set Preamp OFF" :
 			(preamp_level == 1) ? "set Preamp Level 1" :
 			"set Preamp Level 2");
-	set_trace(2, "set_preamp()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_preamp()", hexstr(cmd).c_str());
 }
 
 int RIG_IC7100::get_preamp()
@@ -958,7 +970,7 @@ int RIG_IC7100::get_preamp()
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get Preamp Level")) {
-		get_trace(2, "get_preamp()", str2hex(replystr.c_str(), replystr.length()));
+		get_trace(2, "get_preamp()", hexstr(replystr).c_str());
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
 			preamp_level = replystr[p+6];
@@ -1078,17 +1090,50 @@ void RIG_IC7100::set_cw_vol()
 	cmd += '\x32';
 	cmd.append(to_bcd((int)(progStatus.cw_vol * 2.55), 3));
 	cmd.append( post );
-	set_trace(2, "set_cw_vol()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_cw_vol()", hexstr(cmd).c_str());
 	waitFB("SET cw sidetone volume");
 }
 
+void RIG_IC7100::set_break_in()
+{
+// 16 47 00 break-in off
+// 16 47 01 break-in on
+
+	cmd.assign(pre_to).append("\x16\x47");
+
+	switch (progStatus.break_in) {
+		case 1: cmd += '\x01'; break_in_label("QSK ON");  break;
+		case 0:
+		default: cmd += '\x00'; break_in_label("qsk");
+	}
+	cmd.append(post);
+	waitFB("SET break-in");
+}
+
+int RIG_IC7100::get_break_in()
+{
+	cmd.assign(pre_to).append("\x16\x47").append(post);
+	std::string resp;
+	resp.assign(pre_fm);
+	if (waitFOR(8, "get break in")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos) {
+			progStatus.break_in = replystr[p+6];
+			if (progStatus.break_in == 0) break_in_label("qsk");
+			else  break_in_label("QSK ON");
+		}
+	}
+	get_trace(2, "get_break_in()", hexstr(replystr).c_str());
+	return progStatus.break_in;
+}
+
 void RIG_IC7100::set_power_control(double val)
 {
 	cmd = pre_to;
 	cmd.append("\x14\x0A");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(2, "set_power_control()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_power_control()", hexstr(cmd).c_str());
 	waitFB("set power");
 }
 
@@ -1105,13 +1150,13 @@ int RIG_IC7100::get_power_control()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
-	get_trace(2, "get_power_control()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_power_control()", hexstr(replystr).c_str());
 	return val;
 }
 
 void RIG_IC7100::get_pc_min_max_step(double &min, double &max, double &step)
 {
-	min = 2; max = 100; step = 1;
+	min = 0; pmax = max = 100; step = 1;
 }
 
 void RIG_IC7100::set_rf_gain(int val)
@@ -1127,7 +1172,7 @@ void RIG_IC7100::set_rf_gain(int val)
 	cmd.append("\x14\x02");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(2, "set_rf_gain()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_rf_gain()", hexstr(cmd).c_str());
 	waitFB("set RF");
 }
 
@@ -1151,7 +1196,7 @@ int RIG_IC7100::get_rf_gain()
 		if (p != string::npos)
 			val = num100(replystr.substr(p + 6));
 	}
-	get_trace(2, "get_rf_gain()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_rf_gain()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1167,7 +1212,7 @@ void RIG_IC7100::set_volume_control(int val)
 	cmd.append("\x14\x01");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(2, "set_volume_control()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_volume_control()", hexstr(cmd).c_str());
 	waitFB("set vol");
 }
 
@@ -1185,7 +1230,7 @@ int RIG_IC7100::get_volume_control()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
-	get_trace(2, "get_volume_control()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_volume_control()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1195,7 +1240,7 @@ void RIG_IC7100::set_squelch(int val)
 	cmd.append("\x14\x03");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(2, "set_squelch()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_squelch()", hexstr(cmd).c_str());
 	waitFB("set Sqlch");
 }
 
@@ -1213,7 +1258,7 @@ int  RIG_IC7100::get_squelch()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
-	get_trace(2, "get_squelch()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_squelch()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1253,7 +1298,7 @@ int RIG_IC7100::get_smeter()
 			if (mtr > 100) mtr = 100;
 		}
 	}
-	get_trace(2, "get_smeter()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_smeter()", hexstr(replystr).c_str());
 	return mtr;
 }
 
@@ -1277,24 +1322,24 @@ int RIG_IC7100::get_power_out(void)
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	int mtr= 0;
+	int mtr = 0;
+	int val = 0;
 	if (waitFOR(9, "get power out")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			mtr = fm_bcd(replystr.substr(p+6), 3);
+			mtr = hex2val(replystr.substr(p+6, 2));
+			mtr = max(0, min(mtr, 255));
 			size_t i = 0;
 			for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 					break;
-			if (mtr < 0) mtr = 0;
-			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(pwrtbl[i].val + 
+			val = (int)ceil(pwrtbl[i].val + 
 				(pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
-			if (mtr > 100) mtr = 100;
+			if (val > 100) val = 100;
 		}
 	}
-	get_trace(2, "get_power_out()", str2hex(replystr.c_str(), replystr.length()));
-	return mtr;
+	get_trace(2, "get_power_out()", hexstr(replystr).c_str());
+	return val;
 }
 
 int RIG_IC7100::get_swr()
@@ -1314,7 +1359,7 @@ int RIG_IC7100::get_swr()
 			if (mtr > 100) mtr = 100;
 		}
 	}
-	get_trace(2, "get_swr()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_swr()", hexstr(replystr).c_str());
 	return mtr;
 }
 
@@ -1335,7 +1380,7 @@ int RIG_IC7100::get_alc()
 			if (mtr > 100) mtr = 100;
 		}
 	}
-	get_trace(2, "get_alc()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_alc()", hexstr(replystr).c_str());
 	return mtr;
 }
 
@@ -1373,14 +1418,14 @@ void RIG_IC7100::set_notch(bool on, int freq)
 	cmd += on ? '\x01' : '\x00';
 	cmd.append(post);
 	waitFB("set notch");
-	set_trace(2, "set_notch() ", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_notch() ", hexstr(cmd).c_str());
 
 	cmd = pre_to;
 	cmd.append("\x14\x0D");
 	cmd.append(to_bcd(hexval,3));
 	cmd.append(post);
 	waitFB("set notch val");
-	set_trace(2, "set_notch_val() ", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_notch_val() ", hexstr(cmd).c_str());
 }
 
 bool RIG_IC7100::get_notch(int &val)
@@ -1395,7 +1440,7 @@ bool RIG_IC7100::get_notch(int &val)
 	cmd.append(cstr);
 	cmd.append( post );
 	if (waitFOR(8, "get notch")) {
-		get_trace(2, "get_notch()", str2hex(replystr.c_str(), replystr.length()));
+		get_trace(2, "get_notch()", hexstr(replystr).c_str());
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
 			on = replystr[p + 6];
@@ -1406,7 +1451,7 @@ bool RIG_IC7100::get_notch(int &val)
 		resp.append(cstr);
 		cmd.append(post);
 		if (waitFOR(9, "notch val")) {
-			get_trace(2, "get_notch_val() ", str2hex(replystr.c_str(), replystr.length()));
+			get_trace(2, "get_notch_val() ", hexstr(replystr).c_str());
 			size_t p = replystr.rfind(resp);
 			if (p != string::npos) {
 				val = (int)ceil(fm_bcd(replystr.substr(p+6),3));
@@ -1433,7 +1478,7 @@ bool RIG_IC7100::get_notch(int &val)
 						break;
 				}
 			}
-			get_trace(2, "get_notch_val() ", str2hex(replystr.c_str(), replystr.length()));
+			get_trace(2, "get_notch_val() ", hexstr(replystr).c_str());
 		}
 	}
 	return on;
@@ -1559,7 +1604,7 @@ int RIG_IC7100::get_pbt_inner()
 			val -= 50;
 		}
 	}
-	rig_trace(2, "get_pbt_inner()", str2hex(replystr.c_str(), replystr.length()));
+	rig_trace(2, "get_pbt_inner()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1579,7 +1624,7 @@ int RIG_IC7100::get_pbt_outer()
 			val -= 50;
 		}
 	}
-	rig_trace(2, "get_pbt_outer()", str2hex(replystr.c_str(), replystr.length()));
+	rig_trace(2, "get_pbt_outer()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1596,7 +1641,7 @@ void RIG_IC7100::set_noise(bool val)
 	cmd.append("\x16\x22");
 	cmd += val ? 1 : 0;
 	cmd.append(post);
-	set_trace(2, "set_noise()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_noise()", hexstr(cmd).c_str());
 	waitFB("set noise");
 }
 
@@ -1610,7 +1655,7 @@ int RIG_IC7100::get_noise()
 	cmd.append(post);
 	if (waitFOR(8, "get noise")) {
 		size_t p = replystr.rfind(resp);
-	get_trace(2, "get_noise()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_noise()", hexstr(replystr).c_str());
 	if (p != string::npos)
 		return (replystr[p+6] ? 1 : 0);
 	}
@@ -1624,7 +1669,7 @@ void RIG_IC7100::set_nb_level(int val)
 	cmd.append("\x14\x12");
 	cmd.append(bcd255(val));
 	cmd.append( post );
-	set_trace(2, "set_nb_level()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_nb_level()", hexstr(cmd).c_str());
 	waitFB("set NB level");
 }
 
@@ -1642,7 +1687,7 @@ int  RIG_IC7100::get_nb_level()
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
 	}
-	get_trace(2, "get_nb_level()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_nb_level()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1652,7 +1697,7 @@ void RIG_IC7100::set_noise_reduction(int val)
 	cmd.append("\x16\x40");
 	cmd += val ? 1 : 0;
 	cmd.append(post);
-	set_trace(2, "set_noise_reduction()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_noise_reduction()", hexstr(cmd).c_str());
 	waitFB("set NR");
 }
 
@@ -1666,7 +1711,7 @@ int RIG_IC7100::get_noise_reduction()
 	cmd.append(post);
 	if (waitFOR(8, "get NR")) {
 		size_t p = replystr.rfind(resp);
-	get_trace(2, "get_noise_reduction()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_noise_reduction()", hexstr(replystr).c_str());
 	if (p != string::npos)
 		return (replystr[p+6] ? 1 : 0);
 	}
@@ -1681,7 +1726,7 @@ void RIG_IC7100::set_noise_reduction_val(int val)
 	val += 8;
 	cmd.append(to_bcd(val, 3));
 	cmd.append(post);
-	set_trace(2, "set_noise_reduction_val()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_noise_reduction_val()", hexstr(cmd).c_str());
 	waitFB("set NRval");
 }
 
@@ -1702,7 +1747,7 @@ int RIG_IC7100::get_noise_reduction_val()
 			val /= 16;
 		}
 	}
-	get_trace(2, "get_nr_val()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_nr_val()", hexstr(replystr).c_str());
 	return val;
 }
 
@@ -1735,7 +1780,7 @@ void RIG_IC7100::get_band_selection(int v)
 	cmd.append( post );
 
 	if (waitFOR(56, "get band stack")) {
-		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
+		set_trace(2, "get band stack", hexstr(replystr).c_str());
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
 			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p + 8, 5), 10);
@@ -1773,7 +1818,7 @@ void RIG_IC7100::get_band_selection(int v)
 			}
 		}
 	} else
-		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
+		set_trace(2, "get band stack", hexstr(replystr).c_str());
 }
 
 void RIG_IC7100::set_band_selection(int v)
@@ -1804,7 +1849,7 @@ void RIG_IC7100::set_band_selection(int v)
     cmd.append("                ");                    // byte 39 memory name, 16 chars
 	cmd.append(post);
 	waitFB("set_band_selection");
-	set_trace(2, "set_band_selection()", str2hex(replystr.c_str(), replystr.length()));
+	set_trace(2, "set_band_selection()", hexstr(replystr).c_str());
 }
 
 void RIG_IC7100::setVfoAdj(double v)
@@ -1817,7 +1862,7 @@ void RIG_IC7100::setVfoAdj(double v)
 	cmd.append(bcd255(int(v)));
 	cmd.append(post);
 	waitFB("SET vfo adjust");
-	set_trace(2, "set_vfo_adj()", str2hex(cmd.c_str(), cmd.length()));
+	set_trace(2, "set_vfo_adj()", hexstr(cmd).c_str());
 }
 
 double RIG_IC7100::getVfoAdj()
@@ -1834,7 +1879,7 @@ double RIG_IC7100::getVfoAdj()
 			vfo_ = num100(replystr.substr(p+8));
 		}
 	}
-	get_trace(2, "get_vfo_adj()", str2hex(replystr.c_str(), replystr.length()));
+	get_trace(2, "get_vfo_adj()", hexstr(replystr).c_str());
 	return vfo_;
 }
 
@@ -1860,7 +1905,7 @@ void RIG_IC7100::set_FILT(int filter)
 			cmd += filter;
 		cmd.append( post );
 		waitFB("set mode/filter B");
-		set_trace(2, "set mode/filter B", str2hex(replystr.c_str(), replystr.length()));
+		set_trace(2, "set mode/filter B", hexstr(replystr).c_str());
 
 		if (B.imode >= LSBD7100) {
 			cmd = pre_to;
@@ -1869,7 +1914,7 @@ void RIG_IC7100::set_FILT(int filter)
 			cmd += filter;
 			cmd.append( post);
 			waitFB("set data mode B");
-			set_trace(2, "set data mode B", str2hex(replystr.c_str(), replystr.length()));
+			set_trace(2, "set data mode B", hexstr(replystr).c_str());
 		}
 	} else {
 		A.filter = filter;
@@ -1882,7 +1927,7 @@ void RIG_IC7100::set_FILT(int filter)
 			cmd += filter;
 		cmd.append( post );
 		waitFB("set filter A ");
-		set_trace(2, "set filter A", str2hex(replystr.c_str(), replystr.length()));
+		set_trace(2, "set filter A", hexstr(replystr).c_str());
 
 		if (A.imode >= LSBD7100) {
 			cmd = pre_to;
@@ -1891,7 +1936,7 @@ void RIG_IC7100::set_FILT(int filter)
 			cmd += filter;
 			cmd.append( post);
 			waitFB("set data mode A");
-			set_trace(2, "set data mode A", str2hex(replystr.c_str(), replystr.length()));
+			set_trace(2, "set data mode A", hexstr(replystr).c_str());
 		}
 	}
 }
