@@ -296,20 +296,25 @@ void RIG_IC7300::swapAB()
 
 void RIG_IC7300::set_xcvr_auto_on()
 {
-	cmd.clear();
-	int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
-	if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
-		cmd.append( fes[progStatus.comm_baudrate], '\xFE');
-	}
-	cmd.append(pre_to);
-	cmd += '\x18'; cmd += '\x01';
-	cmd.append(post);
-	waitFB("Power ON", 200);
-
 	cmd = pre_to;
 	cmd += '\x19'; cmd += '\x00';
 	cmd.append(post);
-	waitFOR(8, "get ID", 10000);
+	if (waitFOR(8, "get ID", 100) == false) {
+		cmd.clear();
+		int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
+		if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
+			cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+		}
+		cmd.append(pre_to);
+		cmd += '\x18'; cmd += '\x01';
+		cmd.append(post);
+		waitFB("Power ON", 200);
+		for (int i = 0; i < 5000; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 5000);
+			Fl::awake();
+		}
+	}
 }
 
 void RIG_IC7300::set_xcvr_auto_off()
@@ -1088,7 +1093,7 @@ void RIG_IC7300::set_cw_wpm()
 	waitFB("SET cw wpm");
 }
 
-void RIG_IC7300::enable_break_in()
+void RIG_IC7300::set_break_in()
 {
 // 16 47 00 break-in off
 // 16 47 01 break-in semi
@@ -1106,6 +1111,24 @@ void RIG_IC7300::enable_break_in()
 	waitFB("SET break-in");
 }
 
+int RIG_IC7300::get_break_in()
+{
+	cmd.assign(pre_to).append("\x16\x47").append(post);
+	std::string resp;
+	resp.assign(pre_fm);
+	if (waitFOR(8, "get break in")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos) {
+			progStatus.break_in = replystr[p+6];
+			if (progStatus.break_in == 0) break_in_label("qsk");
+			else  if (progStatus.break_in == 1) break_in_label("SEMI");
+			else  break_in_label("FULL");
+		}
+	}
+	get_trace(2, "get_break_in()", hexstr(replystr).c_str());
+	return progStatus.break_in;
+}
+
 void RIG_IC7300::get_cw_qsk_min_max_step(double &min, double &max, double &step)
 {
 	min = 2.0; max = 13.0; step = 0.1;
@@ -1223,6 +1246,8 @@ void RIG_IC7300::set_power_control(double val)
 	cmd.append(bcd255(val));
 	cmd.append( post );
 	waitFB("set power");
+	set_trace(2, "set power control ", str2hex(replystr.c_str(), replystr.length()));
+
 }
 
 int RIG_IC7300::get_power_control()
@@ -1234,6 +1259,7 @@ int RIG_IC7300::get_power_control()
 	cmd.append(cstr).append(post);
 	resp.append(cstr);
 	if (waitFOR(9, "get power")) {
+		get_trace(2, "get power control ", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
 			val = num100(replystr.substr(p+6));
@@ -1243,7 +1269,7 @@ int RIG_IC7300::get_power_control()
 
 void RIG_IC7300::get_pc_min_max_step(double &min, double &max, double &step)
 {
-	min = 2; max = 100; step = 1;
+	min = 0; pmax = max = 100; step = 1;
 }
 
 int RIG_IC7300::get_smeter()
@@ -1292,23 +1318,23 @@ int RIG_IC7300::get_power_out(void)
 	cmd.append(cstr);
 	cmd.append( post );
 	int mtr= 0;
+	int val = 0;
 	if (waitFOR(9, "get power out")) {
+		get_trace(2, "get power out ", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			mtr = fm_bcd(replystr.substr(p+6), 3);
+			mtr = hex2val(replystr.substr(p+6, 2));
+			mtr = max(0, min(mtr, 255));
 			size_t i = 0;
-			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+			for (i = 0; i < sizeof(pwrtbl) / sizeof(*pwrtbl) - 1; i++)
 				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 					break;
-			if (mtr < 0) mtr = 0;
-			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(pwrtbl[i].pwr + 
+			val = (int)ceil(pwrtbl[i].pwr + 
 				(pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
-			
-			if (mtr > 100) mtr = 100;
+			if (val > 100) val = 100;
 		}
 	}
-	return mtr;
+	return val;
 }
 
 struct swrpair {int mtr; float swr;};
