@@ -316,20 +316,25 @@ void RIG_IC7610::swapAB()
 
 void RIG_IC7610::set_xcvr_auto_on()
 {
-	cmd.clear();
-	int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
-	if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
-		cmd.append( fes[progStatus.comm_baudrate], '\xFE');
-	}
-	cmd.append(pre_to);
-	cmd += '\x18'; cmd += '\x01';
-	cmd.append(post);
-	waitFB("Power ON", 200);
-
 	cmd = pre_to;
 	cmd += '\x19'; cmd += '\x00';
 	cmd.append(post);
-	waitFOR(8, "get ID", 10000);
+	if (waitFOR(8, "get ID", 100) == false) {
+		cmd.clear();
+		int fes[] = { 2, 2, 2, 3, 7, 13, 25, 50, 75, 150, 150, 150 };
+		if (progStatus.comm_baudrate >= 0 && progStatus.comm_baudrate <= 11) {
+			cmd.append( fes[progStatus.comm_baudrate], '\xFE');
+		}
+		cmd.append(pre_to);
+		cmd += '\x18'; cmd += '\x01';
+		cmd.append(post);
+		waitFB("Power ON", 200);
+		for (int i = 0; i < 5000; i += 100) {
+			MilliSleep(100);
+			update_progress(100 * i / 5000);
+			Fl::awake();
+		}
+	}
 }
 
 void RIG_IC7610::set_xcvr_auto_off()
@@ -1111,7 +1116,7 @@ void RIG_IC7610::set_cw_wpm()
 	set_trace(2, "set_cw_wpm() ", str2hex(replystr.c_str(), replystr.length()));
 }
 
-void RIG_IC7610::enable_break_in()
+void RIG_IC7610::set_break_in()
 {
 // 16 47 00 break-in off
 // 16 47 01 break-in semi
@@ -1130,6 +1135,24 @@ void RIG_IC7610::enable_break_in()
 	set_trace(2, "set_break_in() ", str2hex(replystr.c_str(), replystr.length()));
 }
 
+int RIG_IC7610::get_break_in()
+{
+	cmd.assign(pre_to).append("\x16\x47").append(post);
+	std::string resp;
+	resp.assign(pre_fm);
+	if (waitFOR(8, "get break in")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos) {
+			progStatus.break_in = replystr[p+6];
+			if (progStatus.break_in == 0) break_in_label("qsk");
+			else  if (progStatus.break_in == 1) break_in_label("SEMI");
+			else  break_in_label("FULL");
+		}
+	}
+	return progStatus.break_in;
+}
+
+
 void RIG_IC7610::get_cw_qsk_min_max_step(double &min, double &max, double &step)
 {
 	min = 2.0; max = 13.0; step = 0.1;
@@ -1276,7 +1299,7 @@ int RIG_IC7610::get_power_control()
 
 void RIG_IC7610::get_pc_min_max_step(double &min, double &max, double &step)
 {
-	min = 2; max = 100; step = 1;
+	min = 2; pmax = max = 100; step = 1;
 }
 
 int RIG_IC7610::get_smeter()
