@@ -50,9 +50,12 @@ Cserial::Cserial() {
 	baud = 1200;
 	timeout = 50; //msec
 	retries = 5;
-	rts = dtr = false;
-	rtsptt = dtrptt = false;
-	rtscts = false;
+	rts = 
+	dtr = 
+	rtsptt = 
+	dtrptt =
+	rtscts = 
+	serptt = false;
 	status = 0;
 	stopbits = 2;
 	fd = -1;
@@ -84,6 +87,7 @@ bool Cserial::CheckPort(string dev)  {
 ///////////////////////////////////////////////////////
 bool Cserial::OpenPort()  {
 
+	if (IsOpen()) ClosePort();
 	if ((fd = open( device.c_str(), O_RDWR | O_NOCTTY | O_NDELAY )) < 0)
 		return false;
 #if SERIAL_DEBUG
@@ -187,6 +191,19 @@ bool Cserial::OpenPort()  {
 // Function name	: Cserial::setPTT
 // Return type	  : void
 ///////////////////////////////////////////////////////
+
+bool Cserial::RTSptt(){
+	return rtsptt;
+}
+
+bool Cserial::DTRptt(){
+	return dtrptt;
+}
+
+bool Cserial::getPTT() {
+	return serptt;
+}
+
 void Cserial::SetPTT(bool ON)
 {
 	if (fd < 0) {
@@ -221,6 +238,7 @@ void Cserial::SetPTT(bool ON)
 #endif
 		ioctl(fd, TIOCMSET, &status);
 	}
+	serptt = ON;
 //	LOG_DEBUG("No ptt specified");
 }
 
@@ -262,7 +280,7 @@ void Cserial::ClosePort()
 	if (fd < 0) return;
 	int myfd = fd;
 	fd = -1;
-	
+
 // Some serial drivers force RTS and DTR high immediately upon
 // opening the port, so our origstatus will indicate those bits
 // high (though the lines weren't actually high before we opened).
@@ -314,9 +332,9 @@ int  Cserial::ReadBuffer (char *buf, int nchars)
 		}
 		retnum = read (fd, (char *)(buf + nread), nchars);
 		if (retnum < 0)
-			return 0;//nread;
+			return 0;
 		if (retnum == 0)
-			return nread;
+			break;
 		nread += retnum;
 		nchars -= retnum;
 	}
@@ -406,6 +424,8 @@ bool Cserial::OpenPort()
 {
 	if (device.empty()) return false;
 
+	if (IsOpen()) ClosePort();
+
 	string COMportname = "//./";
 	COMportname.append(device);
 
@@ -867,6 +887,18 @@ if (bPortReady == 0) {
 // Function name	: Cserial::setPTT
 // Return type	  : void
 ///////////////////////////////////////////////////////
+bool Cserial::RTSptt(){
+		return rtsptt;
+	}
+
+bool Cserial::DTRptt(){
+		return dtrptt;
+	}
+
+bool Cserial::getPTT() {
+	return serptt;
+}
+
 void Cserial::SetPTT(bool ON)
 {
 	if (hComm == INVALID_HANDLE_VALUE) {
@@ -914,7 +946,7 @@ PTT %d, DTRptt %d, DTR %d, RTSptt %d, RTS %d, RTSCTS %d, DtrControl %2x, RtsCont
 		static_cast<unsigned int>(dcb.fDtrControl), 
 		static_cast<unsigned int>(dcb.fRtsControl) );
 #endif
-
+	serptt = ON;
 	SetCommState(hComm, &dcb);
 }
 
@@ -939,12 +971,15 @@ void Cserial::setRTS(bool b)
 }
 
 Cserial::Cserial() {
-	rts = dtr = false;
-	rtsptt = dtrptt = false;
-	rtscts = false;
+	rts = 
+	dtr = 
+	rtsptt = 
+	dtrptt =
+	rtscts = 
+	serptt = false;
 	baud = CBR_9600;
 	stopbits = 2;
-	hComm = 0;
+	hComm = INVALID_HANDLE_VALUE;
 }
 
 Cserial::Cserial( std::string portname) {
