@@ -73,6 +73,7 @@ static void make_trace_window() {
 	tracebuffer = new Fl_Text_Buffer;
 	tracedisplay->buffer(tracebuffer);
 	tracedisplay->textfont(FL_SCREEN);
+	tracedisplay->wrap_mode(Fl_Text_Display::WRAP_NONE, 100);
 	btn_cleartrace = new Fl_Button(515, 275, 80, 20, _("Clear"));
 	btn_cleartrace->callback((Fl_Callback *)cb_cleartrace);
 	tracewindow->resizable(tracedisplay);
@@ -81,19 +82,23 @@ static void make_trace_window() {
 static void update_tracetext(void *)
 {
 	guard_lock tt(&mutex_trace);
-	for (size_t n = 0; n < tracestrings.size(); n++)
-		tracedisplay->insert(tracestrings[n].c_str());
-	tracestrings.clear();
-}
 
-static void tracefile(std::string s)
-{
 	string trace_fname = RigHomeDir;
 	trace_fname.append("trace.txt");
 	ofstream tfile(trace_fname.c_str(), ios::app);
-	if (tfile)
-		tfile << s;
+	if (tfile)  {
+		for (size_t n = 0; n < tracestrings.size(); n++)
+			tfile << tracestrings[n];
+	}
 	tfile.close();
+
+	if (tracewindow->visible()) {
+		if (tracedisplay->buffer()->length() > 100000)
+			tracedisplay->buffer()->text("");
+		for (size_t n = 0; n < tracestrings.size(); n++)
+			tracedisplay->insert(tracestrings[n].c_str());
+	}
+    tracestrings.clear();
 }
 
 void trace(int n, ...) // all args of type const char *
@@ -111,11 +116,10 @@ void trace(int n, ...) // all args of type const char *
 		s << " " << va_arg(vl, const char *);
 	va_end(vl);
 	s << "\n";
-	tracefile(s.str());
 
 	guard_lock tt(&mutex_trace);
-	tracestrings.push_back(s.str());
-	Fl::awake(update_tracetext);
+		tracestrings.push_back(s.str());
+		Fl::awake(update_tracetext);
 }
 
 void xml_trace(int n, ...) // all args of type const char *
@@ -133,11 +137,10 @@ void xml_trace(int n, ...) // all args of type const char *
 		s << " " << va_arg(vl, const char *);
 	va_end(vl);
 	s << "\n";
-	tracefile(s.str());
 
 	guard_lock tt(&mutex_trace);
-	tracestrings.push_back(s.str());
-	Fl::awake(update_tracetext);
+		tracestrings.push_back(s.str());
+		Fl::awake(update_tracetext);
 }
 
 void rig_trace(int n, ...) // all args of type const char *
@@ -155,11 +158,10 @@ void rig_trace(int n, ...) // all args of type const char *
 		s << " " << va_arg(vl, const char *);
 	va_end(vl);
 	s << "\n";
-	tracefile(s.str());
 
 	guard_lock tt(&mutex_trace);
-	tracestrings.push_back(s.str());
-	Fl::awake(update_tracetext);
+		tracestrings.push_back(s.str());
+		Fl::awake(update_tracetext);
 }
 
 void set_trace(int n, ...) // all args of type const char *
@@ -177,11 +179,10 @@ void set_trace(int n, ...) // all args of type const char *
 		s << " " << va_arg(vl, const char *);
 	va_end(vl);
 	s << "\n";
-	tracefile(s.str());
 
 	guard_lock tt(&mutex_trace);
-	tracestrings.push_back(s.str());
-	Fl::awake(update_tracetext);
+		tracestrings.push_back(s.str());
+		Fl::awake(update_tracetext);
 }
 
 void get_trace(int n, ...) // all args of type const char *
@@ -199,11 +200,10 @@ void get_trace(int n, ...) // all args of type const char *
 		s << " " << va_arg(vl, const char *);
 	va_end(vl);
 	s << "\n";
-	tracefile(s.str());
 
 	guard_lock tt(&mutex_trace);
-	tracestrings.push_back(s.str());
-	Fl::awake(update_tracetext);
+		tracestrings.push_back(s.str());
+		Fl::awake(update_tracetext);
 }
 
 void rpc_trace(int n, ...) // all args of type const char *
@@ -262,10 +262,8 @@ void rpc_trace(int n, ...) // all args of type const char *
 
 	if (str[str.length()-1] != '\n') str += '\n';
 
-	tracefile(str);
-
 	guard_lock tt(&mutex_trace);
-	tracestrings.push_back(str);
-	Fl::awake(update_tracetext);
+		tracestrings.push_back(str);
+		Fl::awake(update_tracetext);
 }
 
